.. currentmodule:: abjad.tools.scoretools

make_repeated_notes_with_shorter_notes_at_end
=============================================

.. autofunction:: make_repeated_notes_with_shorter_notes_at_end
